# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TeamMemberNotificationModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'notification_groups': 'list[NotificationGroupModel]',
        'vacation': 'bool',
        'hide_system_messages': 'bool'
    }

    attribute_map = {
        'notification_groups': 'notificationGroups',
        'vacation': 'vacation',
        'hide_system_messages': 'hideSystemMessages'
    }

    def __init__(self, notification_groups=None, vacation=None, hide_system_messages=None):  # noqa: E501
        """TeamMemberNotificationModel - a model defined in Swagger"""  # noqa: E501
        self._notification_groups = None
        self._vacation = None
        self._hide_system_messages = None
        self.discriminator = None
        self.notification_groups = notification_groups
        if vacation is not None:
            self.vacation = vacation
        if hide_system_messages is not None:
            self.hide_system_messages = hide_system_messages

    @property
    def notification_groups(self):
        """Gets the notification_groups of this TeamMemberNotificationModel.  # noqa: E501

        The Notification preferences.  # noqa: E501

        :return: The notification_groups of this TeamMemberNotificationModel.  # noqa: E501
        :rtype: list[NotificationGroupModel]
        """
        return self._notification_groups

    @notification_groups.setter
    def notification_groups(self, notification_groups):
        """Sets the notification_groups of this TeamMemberNotificationModel.

        The Notification preferences.  # noqa: E501

        :param notification_groups: The notification_groups of this TeamMemberNotificationModel.  # noqa: E501
        :type: list[NotificationGroupModel]
        """
        if notification_groups is None:
            raise ValueError("Invalid value for `notification_groups`, must not be `None`")  # noqa: E501

        self._notification_groups = notification_groups

    @property
    def vacation(self):
        """Gets the vacation of this TeamMemberNotificationModel.  # noqa: E501


        :return: The vacation of this TeamMemberNotificationModel.  # noqa: E501
        :rtype: bool
        """
        return self._vacation

    @vacation.setter
    def vacation(self, vacation):
        """Sets the vacation of this TeamMemberNotificationModel.


        :param vacation: The vacation of this TeamMemberNotificationModel.  # noqa: E501
        :type: bool
        """

        self._vacation = vacation

    @property
    def hide_system_messages(self):
        """Gets the hide_system_messages of this TeamMemberNotificationModel.  # noqa: E501


        :return: The hide_system_messages of this TeamMemberNotificationModel.  # noqa: E501
        :rtype: bool
        """
        return self._hide_system_messages

    @hide_system_messages.setter
    def hide_system_messages(self, hide_system_messages):
        """Sets the hide_system_messages of this TeamMemberNotificationModel.


        :param hide_system_messages: The hide_system_messages of this TeamMemberNotificationModel.  # noqa: E501
        :type: bool
        """

        self._hide_system_messages = hide_system_messages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TeamMemberNotificationModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamMemberNotificationModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.contact_list_contacts_api import ContactListContactsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestContactListContactsApi(unittest.TestCase):
    """ContactListContactsApi unit test stubs"""

    def setUp(self):
        self.api = ContactListContactsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_contact_list_contacts(self):
        """Test case for add_contact_list_contacts

        Add multiple contacts to a Contact List  # noqa: E501
        """
        pass

    def test_delete_contact_list_member(self):
        """Test case for delete_contact_list_member

        Delete a contact from a Contact List  # noqa: E501
        """
        pass

    def test_get_contacts(self):
        """Test case for get_contacts

        Gets all the contacts in a Contact List  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BotModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'display_name': 'str',
        'created_timestamp': 'int',
        'user_type': 'str',
        'name': 'str',
        'api_id': 'str',
        'behavior_type': 'str',
        'type': 'str',
        'avatar_url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'display_name': 'displayName',
        'created_timestamp': 'createdTimestamp',
        'user_type': 'userType',
        'name': 'name',
        'api_id': 'apiId',
        'behavior_type': 'behaviorType',
        'type': 'type',
        'avatar_url': 'avatarUrl'
    }

    def __init__(self, id=None, display_name=None, created_timestamp=None, user_type=None, name=None, api_id=None, behavior_type=None, type=None, avatar_url=None):  # noqa: E501
        """BotModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._display_name = None
        self._created_timestamp = None
        self._user_type = None
        self._name = None
        self._api_id = None
        self._behavior_type = None
        self._type = None
        self._avatar_url = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if display_name is not None:
            self.display_name = display_name
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if user_type is not None:
            self.user_type = user_type
        if name is not None:
            self.name = name
        if api_id is not None:
            self.api_id = api_id
        if behavior_type is not None:
            self.behavior_type = behavior_type
        self.type = type
        self.avatar_url = avatar_url

    @property
    def id(self):
        """Gets the id of this BotModel.  # noqa: E501

        The system generated unique id for this user.  # noqa: E501

        :return: The id of this BotModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BotModel.

        The system generated unique id for this user.  # noqa: E501

        :param id: The id of this BotModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def display_name(self):
        """Gets the display_name of this BotModel.  # noqa: E501

        The display name of this user.  # noqa: E501

        :return: The display_name of this BotModel.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this BotModel.

        The display name of this user.  # noqa: E501

        :param display_name: The display_name of this BotModel.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this BotModel.  # noqa: E501

        The time the user was created.  # noqa: E501

        :return: The created_timestamp of this BotModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this BotModel.

        The time the user was created.  # noqa: E501

        :param created_timestamp: The created_timestamp of this BotModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def user_type(self):
        """Gets the user_type of this BotModel.  # noqa: E501

        The user type for this team member.  # noqa: E501

        :return: The user_type of this BotModel.  # noqa: E501
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this BotModel.

        The user type for this team member.  # noqa: E501

        :param user_type: The user_type of this BotModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["TEAM_MEMBER", "CUSTOMER", "BOT", "SYSTEM", "TROUBLESHOOTING", "INSTANT_APP"]  # noqa: E501
        if user_type not in allowed_values:
            raise ValueError(
                "Invalid value for `user_type` ({0}), must be one of {1}"  # noqa: E501
                .format(user_type, allowed_values)
            )

        self._user_type = user_type

    @property
    def name(self):
        """Gets the name of this BotModel.  # noqa: E501

        The name of this bot.  # noqa: E501

        :return: The name of this BotModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BotModel.

        The name of this bot.  # noqa: E501

        :param name: The name of this BotModel.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def api_id(self):
        """Gets the api_id of this BotModel.  # noqa: E501

        The programmatic, unique id of this bot.  # noqa: E501

        :return: The api_id of this BotModel.  # noqa: E501
        :rtype: str
        """
        return self._api_id

    @api_id.setter
    def api_id(self, api_id):
        """Sets the api_id of this BotModel.

        The programmatic, unique id of this bot.  # noqa: E501

        :param api_id: The api_id of this BotModel.  # noqa: E501
        :type: str
        """

        self._api_id = api_id

    @property
    def behavior_type(self):
        """Gets the behavior_type of this BotModel.  # noqa: E501

        Specify when this bot will respond, depending on agent activity in this conversation.  # noqa: E501

        :return: The behavior_type of this BotModel.  # noqa: E501
        :rtype: str
        """
        return self._behavior_type

    @behavior_type.setter
    def behavior_type(self, behavior_type):
        """Sets the behavior_type of this BotModel.

        Specify when this bot will respond, depending on agent activity in this conversation.  # noqa: E501

        :param behavior_type: The behavior_type of this BotModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["NO_AGENT", "INACTIVE_AGENTS", "ALWAYS"]  # noqa: E501
        if behavior_type not in allowed_values:
            raise ValueError(
                "Invalid value for `behavior_type` ({0}), must be one of {1}"  # noqa: E501
                .format(behavior_type, allowed_values)
            )

        self._behavior_type = behavior_type

    @property
    def type(self):
        """Gets the type of this BotModel.  # noqa: E501

        The type of this bot  # noqa: E501

        :return: The type of this BotModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BotModel.

        The type of this bot  # noqa: E501

        :param type: The type of this BotModel.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["ALTERRA", "CUSTOM", "KEYWORD", "START_STOP", "BOOT"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def avatar_url(self):
        """Gets the avatar_url of this BotModel.  # noqa: E501

        The url of the avatar for this bot to use when posting in live chat.  # noqa: E501

        :return: The avatar_url of this BotModel.  # noqa: E501
        :rtype: str
        """
        return self._avatar_url

    @avatar_url.setter
    def avatar_url(self, avatar_url):
        """Sets the avatar_url of this BotModel.

        The url of the avatar for this bot to use when posting in live chat.  # noqa: E501

        :param avatar_url: The avatar_url of this BotModel.  # noqa: E501
        :type: str
        """
        if avatar_url is None:
            raise ValueError("Invalid value for `avatar_url`, must not be `None`")  # noqa: E501

        self._avatar_url = avatar_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BotModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BotModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class OrgChannelsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_org_channel1(self, **kwargs):  # noqa: E501
        """Creates an org channel  # noqa: E501

        _in snippets: platform.api.orgChannels.addOrgChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_org_channel1(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OrgChannelModel body:
        :param bool assign_to_everyone:
        :return: OrgChannelModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_org_channel1_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_org_channel1_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_org_channel1_with_http_info(self, **kwargs):  # noqa: E501
        """Creates an org channel  # noqa: E501

        _in snippets: platform.api.orgChannels.addOrgChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_org_channel1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OrgChannelModel body:
        :param bool assign_to_everyone:
        :return: OrgChannelModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'assign_to_everyone']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_org_channel1" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'assign_to_everyone' in params:
            query_params.append(('assignToEveryone', params['assign_to_everyone']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/org_channels', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrgChannelModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_org_channel1(self, org_channel_id, **kwargs):  # noqa: E501
        """Delete an org channel  # noqa: E501

        _in snippets: platform.api.orgChannels.deleteOrgChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_org_channel1(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :return: DeleteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_org_channel1_with_http_info(org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_org_channel1_with_http_info(org_channel_id, **kwargs)  # noqa: E501
            return data

    def delete_org_channel1_with_http_info(self, org_channel_id, **kwargs):  # noqa: E501
        """Delete an org channel  # noqa: E501

        _in snippets: platform.api.orgChannels.deleteOrgChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_org_channel1_with_http_info(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :return: DeleteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_org_channel1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `delete_org_channel1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/org_channels/{orgChannelId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_org_channel(self, org_channel_id, **kwargs):  # noqa: E501
        """Gets the details for a specific org channel  # noqa: E501

        _in snippets: platform.api.orgChannels.getOrgChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channel(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :return: OrgChannelModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_org_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_org_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
            return data

    def get_org_channel_with_http_info(self, org_channel_id, **kwargs):  # noqa: E501
        """Gets the details for a specific org channel  # noqa: E501

        _in snippets: platform.api.orgChannels.getOrgChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channel_with_http_info(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :return: OrgChannelModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_org_channel" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_org_channel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/org_channels/{orgChannelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrgChannelModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_org_channel_conversations(self, org_channel_id, **kwargs):  # noqa: E501
        """Gets the conversation details for a specific org channel  # noqa: E501

        _in snippets: platform.api.orgChannels.getOrgChannelConversations_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channel_conversations(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :return: OrgChannelConversationsModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_org_channel_conversations_with_http_info(org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_org_channel_conversations_with_http_info(org_channel_id, **kwargs)  # noqa: E501
            return data

    def get_org_channel_conversations_with_http_info(self, org_channel_id, **kwargs):  # noqa: E501
        """Gets the conversation details for a specific org channel  # noqa: E501

        _in snippets: platform.api.orgChannels.getOrgChannelConversations_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channel_conversations_with_http_info(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :return: OrgChannelConversationsModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_org_channel_conversations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_org_channel_conversations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/org_channels/{orgChannelId}/conversations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrgChannelConversationsModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_org_channels1(self, **kwargs):  # noqa: E501
        """Gets all the org channels for the org  # noqa: E501

        _in snippets: platform.api.orgChannels.getOrgChannels_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channels1(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int first:
        :param int max:
        :param str type:
        :return: OrgChannelModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_org_channels1_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_org_channels1_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_org_channels1_with_http_info(self, **kwargs):  # noqa: E501
        """Gets all the org channels for the org  # noqa: E501

        _in snippets: platform.api.orgChannels.getOrgChannels_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_org_channels1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int first:
        :param int max:
        :param str type:
        :return: OrgChannelModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['first', 'max', 'type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_org_channels1" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501
        if 'type' in params:
            query_params.append(('type', params['type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/org_channels', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrgChannelModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pool_subchannel(self, org_channel_id, subchannel_id, **kwargs):  # noqa: E501
        """For pool channels, gets the details of a specific subchannel in the pool  # noqa: E501

        _in snippets: platform.api.orgChannels.getPoolSubchannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pool_subchannel(org_channel_id, subchannel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :param int subchannel_id: (required)
        :return: PoolSubchannelModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_pool_subchannel_with_http_info(org_channel_id, subchannel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_pool_subchannel_with_http_info(org_channel_id, subchannel_id, **kwargs)  # noqa: E501
            return data

    def get_pool_subchannel_with_http_info(self, org_channel_id, subchannel_id, **kwargs):  # noqa: E501
        """For pool channels, gets the details of a specific subchannel in the pool  # noqa: E501

        _in snippets: platform.api.orgChannels.getPoolSubchannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pool_subchannel_with_http_info(org_channel_id, subchannel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :param int subchannel_id: (required)
        :return: PoolSubchannelModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id', 'subchannel_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pool_subchannel" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_pool_subchannel`")  # noqa: E501
        # verify the required parameter 'subchannel_id' is set
        if ('subchannel_id' not in params or
                params['subchannel_id'] is None):
            raise ValueError("Missing the required parameter `subchannel_id` when calling `get_pool_subchannel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501
        if 'subchannel_id' in params:
            path_params['subchannelId'] = params['subchannel_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/org_channels/{orgChannelId}/subchannels/{subchannelId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PoolSubchannelModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pool_subchannels(self, org_channel_id, **kwargs):  # noqa: E501
        """For pool channels, gets the subchannels in the pool  # noqa: E501

        _in snippets: platform.api.orgChannels.getPoolSubchannels_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pool_subchannels(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :param int first:
        :param int max:
        :return: PoolSubchannelModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_pool_subchannels_with_http_info(org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_pool_subchannels_with_http_info(org_channel_id, **kwargs)  # noqa: E501
            return data

    def get_pool_subchannels_with_http_info(self, org_channel_id, **kwargs):  # noqa: E501
        """For pool channels, gets the subchannels in the pool  # noqa: E501

        _in snippets: platform.api.orgChannels.getPoolSubchannels_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pool_subchannels_with_http_info(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :param int first:
        :param int max:
        :return: PoolSubchannelModelPage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id', 'first', 'max']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pool_subchannels" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `get_pool_subchannels`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []
        if 'first' in params:
            query_params.append(('first', params['first']))  # noqa: E501
        if 'max' in params:
            query_params.append(('max', params['max']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/org_channels/{orgChannelId}/subchannels', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PoolSubchannelModelPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_org_channel(self, org_channel_id, **kwargs):  # noqa: E501
        """Updates an org channel  # noqa: E501

        _in snippets: platform.api.orgChannels.updateOrgChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_org_channel(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :param OrgChannelModel body:
        :return: OrgChannelModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_org_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_org_channel_with_http_info(org_channel_id, **kwargs)  # noqa: E501
            return data

    def update_org_channel_with_http_info(self, org_channel_id, **kwargs):  # noqa: E501
        """Updates an org channel  # noqa: E501

        _in snippets: platform.api.orgChannels.updateOrgChannel_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_org_channel_with_http_info(org_channel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_channel_id: The apiId or internal id (required)
        :param OrgChannelModel body:
        :return: OrgChannelModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_channel_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_org_channel" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_channel_id' is set
        if ('org_channel_id' not in params or
                params['org_channel_id'] is None):
            raise ValueError("Missing the required parameter `org_channel_id` when calling `update_org_channel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_channel_id' in params:
            path_params['orgChannelId'] = params['org_channel_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/org_channels/{orgChannelId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrgChannelModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.pounces_api import PouncesApi  # noqa: E501
from swagger_client.rest import ApiException


class TestPouncesApi(unittest.TestCase):
    """PouncesApi unit test stubs"""

    def setUp(self):
        self.api = PouncesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_pounce(self):
        """Test case for add_pounce

        Creates a pounce  # noqa: E501
        """
        pass

    def test_delete_pounce(self):
        """Test case for delete_pounce

        Deletes the pounce  # noqa: E501
        """
        pass

    def test_get_team_member_pounces(self):
        """Test case for get_team_member_pounces

        Gets all pounces assigned to a team member  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.orgs_api import OrgsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestOrgsApi(unittest.TestCase):
    """OrgsApi unit test stubs"""

    def setUp(self):
        self.api = OrgsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_org(self):
        """Test case for get_org

        Gets information about a specific org based on its ID  # noqa: E501
        """
        pass

    def test_get_org_by_subdomain(self):
        """Test case for get_org_by_subdomain

        Gets an org by its subdomain  # noqa: E501
        """
        pass

    def test_get_org_settings_model(self):
        """Test case for get_org_settings_model

        Gets OrgSettings of the org  # noqa: E501
        """
        pass

    def test_set_org_settings(self):
        """Test case for set_org_settings

        Sets OrgSettings of the org  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OrgMessagingSettingsModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'delivery_restrictions_mode': 'str',
        'delivery_suspend_hour': 'int',
        'delivery_suspend_minute': 'int',
        'delivery_resume_hour': 'int',
        'delivery_resume_minute': 'int'
    }

    attribute_map = {
        'delivery_restrictions_mode': 'deliveryRestrictionsMode',
        'delivery_suspend_hour': 'deliverySuspendHour',
        'delivery_suspend_minute': 'deliverySuspendMinute',
        'delivery_resume_hour': 'deliveryResumeHour',
        'delivery_resume_minute': 'deliveryResumeMinute'
    }

    def __init__(self, delivery_restrictions_mode=None, delivery_suspend_hour=None, delivery_suspend_minute=None, delivery_resume_hour=None, delivery_resume_minute=None):  # noqa: E501
        """OrgMessagingSettingsModel - a model defined in Swagger"""  # noqa: E501
        self._delivery_restrictions_mode = None
        self._delivery_suspend_hour = None
        self._delivery_suspend_minute = None
        self._delivery_resume_hour = None
        self._delivery_resume_minute = None
        self.discriminator = None
        if delivery_restrictions_mode is not None:
            self.delivery_restrictions_mode = delivery_restrictions_mode
        if delivery_suspend_hour is not None:
            self.delivery_suspend_hour = delivery_suspend_hour
        if delivery_suspend_minute is not None:
            self.delivery_suspend_minute = delivery_suspend_minute
        if delivery_resume_hour is not None:
            self.delivery_resume_hour = delivery_resume_hour
        if delivery_resume_minute is not None:
            self.delivery_resume_minute = delivery_resume_minute

    @property
    def delivery_restrictions_mode(self):
        """Gets the delivery_restrictions_mode of this OrgMessagingSettingsModel.  # noqa: E501

        The mode indicating which message delivery restrictions should be applied.  # noqa: E501

        :return: The delivery_restrictions_mode of this OrgMessagingSettingsModel.  # noqa: E501
        :rtype: str
        """
        return self._delivery_restrictions_mode

    @delivery_restrictions_mode.setter
    def delivery_restrictions_mode(self, delivery_restrictions_mode):
        """Sets the delivery_restrictions_mode of this OrgMessagingSettingsModel.

        The mode indicating which message delivery restrictions should be applied.  # noqa: E501

        :param delivery_restrictions_mode: The delivery_restrictions_mode of this OrgMessagingSettingsModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["NORMAL", "SUSPENDED", "SCHEDULED"]  # noqa: E501
        if delivery_restrictions_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `delivery_restrictions_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(delivery_restrictions_mode, allowed_values)
            )

        self._delivery_restrictions_mode = delivery_restrictions_mode

    @property
    def delivery_suspend_hour(self):
        """Gets the delivery_suspend_hour of this OrgMessagingSettingsModel.  # noqa: E501

        The hour (between 0 and 23) that message delivery should be suspended.  # noqa: E501

        :return: The delivery_suspend_hour of this OrgMessagingSettingsModel.  # noqa: E501
        :rtype: int
        """
        return self._delivery_suspend_hour

    @delivery_suspend_hour.setter
    def delivery_suspend_hour(self, delivery_suspend_hour):
        """Sets the delivery_suspend_hour of this OrgMessagingSettingsModel.

        The hour (between 0 and 23) that message delivery should be suspended.  # noqa: E501

        :param delivery_suspend_hour: The delivery_suspend_hour of this OrgMessagingSettingsModel.  # noqa: E501
        :type: int
        """

        self._delivery_suspend_hour = delivery_suspend_hour

    @property
    def delivery_suspend_minute(self):
        """Gets the delivery_suspend_minute of this OrgMessagingSettingsModel.  # noqa: E501

        The minute (between 0 and 59) that message delivery should be suspended.  # noqa: E501

        :return: The delivery_suspend_minute of this OrgMessagingSettingsModel.  # noqa: E501
        :rtype: int
        """
        return self._delivery_suspend_minute

    @delivery_suspend_minute.setter
    def delivery_suspend_minute(self, delivery_suspend_minute):
        """Sets the delivery_suspend_minute of this OrgMessagingSettingsModel.

        The minute (between 0 and 59) that message delivery should be suspended.  # noqa: E501

        :param delivery_suspend_minute: The delivery_suspend_minute of this OrgMessagingSettingsModel.  # noqa: E501
        :type: int
        """

        self._delivery_suspend_minute = delivery_suspend_minute

    @property
    def delivery_resume_hour(self):
        """Gets the delivery_resume_hour of this OrgMessagingSettingsModel.  # noqa: E501

        The hour (between 0 and 23) that message delivery should resume.  # noqa: E501

        :return: The delivery_resume_hour of this OrgMessagingSettingsModel.  # noqa: E501
        :rtype: int
        """
        return self._delivery_resume_hour

    @delivery_resume_hour.setter
    def delivery_resume_hour(self, delivery_resume_hour):
        """Sets the delivery_resume_hour of this OrgMessagingSettingsModel.

        The hour (between 0 and 23) that message delivery should resume.  # noqa: E501

        :param delivery_resume_hour: The delivery_resume_hour of this OrgMessagingSettingsModel.  # noqa: E501
        :type: int
        """

        self._delivery_resume_hour = delivery_resume_hour

    @property
    def delivery_resume_minute(self):
        """Gets the delivery_resume_minute of this OrgMessagingSettingsModel.  # noqa: E501

        The minute (between 0 and 59) that message delivery should resume.  # noqa: E501

        :return: The delivery_resume_minute of this OrgMessagingSettingsModel.  # noqa: E501
        :rtype: int
        """
        return self._delivery_resume_minute

    @delivery_resume_minute.setter
    def delivery_resume_minute(self, delivery_resume_minute):
        """Sets the delivery_resume_minute of this OrgMessagingSettingsModel.

        The minute (between 0 and 59) that message delivery should resume.  # noqa: E501

        :param delivery_resume_minute: The delivery_resume_minute of this OrgMessagingSettingsModel.  # noqa: E501
        :type: int
        """

        self._delivery_resume_minute = delivery_resume_minute

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrgMessagingSettingsModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrgMessagingSettingsModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.org_settings_api import OrgSettingsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestOrgSettingsApi(unittest.TestCase):
    """OrgSettingsApi unit test stubs"""

    def setUp(self):
        self.api = OrgSettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_messaging_settings(self):
        """Test case for get_messaging_settings

        Gets current messaging settings  # noqa: E501
        """
        pass

    def test_get_settings(self):
        """Test case for get_settings

        Gets current settings  # noqa: E501
        """
        pass

    def test_update_messaging_settings(self):
        """Test case for update_messaging_settings

        Updates messaging settings  # noqa: E501
        """
        pass

    def test_update_settings(self):
        """Test case for update_settings

        Updates settings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OrgExternalIdModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'value': 'str',
        'proxy_url': 'str',
        'org_id': 'int'
    }

    attribute_map = {
        'type': 'type',
        'value': 'value',
        'proxy_url': 'proxyUrl',
        'org_id': 'orgId'
    }

    def __init__(self, type=None, value=None, proxy_url=None, org_id=None):  # noqa: E501
        """OrgExternalIdModel - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._value = None
        self._proxy_url = None
        self._org_id = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if value is not None:
            self.value = value
        if proxy_url is not None:
            self.proxy_url = proxy_url
        if org_id is not None:
            self.org_id = org_id

    @property
    def type(self):
        """Gets the type of this OrgExternalIdModel.  # noqa: E501

        The type of the external id, type & value combined must be unique  # noqa: E501

        :return: The type of this OrgExternalIdModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OrgExternalIdModel.

        The type of the external id, type & value combined must be unique  # noqa: E501

        :param type: The type of this OrgExternalIdModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["SALESFORCE", "BLACKBAUD"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def value(self):
        """Gets the value of this OrgExternalIdModel.  # noqa: E501

        The value of external id, type & value combined must be unique  # noqa: E501

        :return: The value of this OrgExternalIdModel.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this OrgExternalIdModel.

        The value of external id, type & value combined must be unique  # noqa: E501

        :param value: The value of this OrgExternalIdModel.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def proxy_url(self):
        """Gets the proxy_url of this OrgExternalIdModel.  # noqa: E501

        If not null, the cluster to proxy connect requests to  # noqa: E501

        :return: The proxy_url of this OrgExternalIdModel.  # noqa: E501
        :rtype: str
        """
        return self._proxy_url

    @proxy_url.setter
    def proxy_url(self, proxy_url):
        """Sets the proxy_url of this OrgExternalIdModel.

        If not null, the cluster to proxy connect requests to  # noqa: E501

        :param proxy_url: The proxy_url of this OrgExternalIdModel.  # noqa: E501
        :type: str
        """

        self._proxy_url = proxy_url

    @property
    def org_id(self):
        """Gets the org_id of this OrgExternalIdModel.  # noqa: E501

        If not null, the internal global org associated with this id  # noqa: E501

        :return: The org_id of this OrgExternalIdModel.  # noqa: E501
        :rtype: int
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this OrgExternalIdModel.

        If not null, the internal global org associated with this id  # noqa: E501

        :param org_id: The org_id of this OrgExternalIdModel.  # noqa: E501
        :type: int
        """

        self._org_id = org_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrgExternalIdModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrgExternalIdModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.integrations_api import IntegrationsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestIntegrationsApi(unittest.TestCase):
    """IntegrationsApi unit test stubs"""

    def setUp(self):
        self.api = IntegrationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_integration(self):
        """Test case for add_integration

        Creates an integration  # noqa: E501
        """
        pass

    def test_delete_integration(self):
        """Test case for delete_integration

        Deletes a integration  # noqa: E501
        """
        pass

    def test_get_integration(self):
        """Test case for get_integration

        Gets a single integration  # noqa: E501
        """
        pass

    def test_get_integrations(self):
        """Test case for get_integrations

        Gets all the integrations  # noqa: E501
        """
        pass

    def test_update_integration(self):
        """Test case for update_integration

        Update an integration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.analytics_api import AnalyticsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestAnalyticsApi(unittest.TestCase):
    """AnalyticsApi unit test stubs"""

    def setUp(self):
        self.api = AnalyticsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_agent_activity_report(self):
        """Test case for get_agent_activity_report

        Get the Agent Activity Report for the org.  # noqa: E501
        """
        pass

    def test_get_agent_activity_report_for_channel(self):
        """Test case for get_agent_activity_report_for_channel

        Get the Agent Activity Report for a specific channel.  # noqa: E501
        """
        pass

    def test_get_channel_report(self):
        """Test case for get_channel_report

        Get the Channel Report for the org.  # noqa: E501
        """
        pass

    def test_get_contact_action_report(self):
        """Test case for get_contact_action_report

        Get the Contact Action Report for the org  # noqa: E501
        """
        pass

    def test_get_custom_counters_report(self):
        """Test case for get_custom_counters_report

        Get the Custom Counters Report for the org  # noqa: E501
        """
        pass

    def test_get_custom_counters_report_for_schema(self):
        """Test case for get_custom_counters_report_for_schema

        Get the Custom Counters Report for a specific schemaId  # noqa: E501
        """
        pass

    def test_get_customer_engagement_report(self):
        """Test case for get_customer_engagement_report

        Get the Customer Engagement Report for the org  # noqa: E501
        """
        pass

    def test_get_customer_engagement_report_for_channel(self):
        """Test case for get_customer_engagement_report_for_channel

        Get the Customer Engagement Report for a specific channel  # noqa: E501
        """
        pass

    def test_get_error_report(self):
        """Test case for get_error_report

        Get the Error Report for the org  # noqa: E501
        """
        pass

    def test_get_instant_app_report(self):
        """Test case for get_instant_app_report

        Get the Instant App Report for the org  # noqa: E501
        """
        pass

    def test_get_instant_app_report_for_schema(self):
        """Test case for get_instant_app_report_for_schema

        Get the Instant App Report for a specific schema  # noqa: E501
        """
        pass

    def test_get_instant_app_schema_report(self):
        """Test case for get_instant_app_schema_report

        Get the Instant App Report for the org  # noqa: E501
        """
        pass

    def test_get_kpi_report(self):
        """Test case for get_kpi_report

        Get the KPI Report for the org  # noqa: E501
        """
        pass

    def test_get_messaging_report(self):
        """Test case for get_messaging_report

        Get the Messaging Report for the org  # noqa: E501
        """
        pass

    def test_get_messaging_report_for_channel(self):
        """Test case for get_messaging_report_for_channel

        Get the Messaging Report for a specific channel  # noqa: E501
        """
        pass

    def test_get_opt_out_report(self):
        """Test case for get_opt_out_report

        Get the Opt-Out Report for the org.  # noqa: E501
        """
        pass

    def test_get_opt_out_report_for_channel(self):
        """Test case for get_opt_out_report_for_channel

        Get the Opt-Out Report for a specific channel  # noqa: E501
        """
        pass

    def test_get_org_activity_report(self):
        """Test case for get_org_activity_report

        Get the Org Activity Report totals.  # noqa: E501
        """
        pass

    def test_get_org_activity_report_for_channel(self):
        """Test case for get_org_activity_report_for_channel

        Get the Org Activity Report totals for a specific channel.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class PouncesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_pounce(self, **kwargs):  # noqa: E501
        """Creates a pounce  # noqa: E501

        _in snippets: platform.api.pounces.addPounce_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_pounce(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PounceModel body:
        :return: PounceModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_pounce_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_pounce_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_pounce_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a pounce  # noqa: E501

        _in snippets: platform.api.pounces.addPounce_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_pounce_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PounceModel body:
        :return: PounceModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_pounce" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/pounces', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PounceModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_pounce(self, pounce_id, **kwargs):  # noqa: E501
        """Deletes the pounce  # noqa: E501

        _in snippets: platform.api.pounces.deletePounce_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_pounce(pounce_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int pounce_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_pounce_with_http_info(pounce_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_pounce_with_http_info(pounce_id, **kwargs)  # noqa: E501
            return data

    def delete_pounce_with_http_info(self, pounce_id, **kwargs):  # noqa: E501
        """Deletes the pounce  # noqa: E501

        _in snippets: platform.api.pounces.deletePounce_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_pounce_with_http_info(pounce_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int pounce_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pounce_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_pounce" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'pounce_id' is set
        if ('pounce_id' not in params or
                params['pounce_id'] is None):
            raise ValueError("Missing the required parameter `pounce_id` when calling `delete_pounce`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'pounce_id' in params:
            path_params['pounceId'] = params['pounce_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/pounces/{pounceId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_member_pounces(self, team_member_id, **kwargs):  # noqa: E501
        """Gets all pounces assigned to a team member  # noqa: E501

        _in snippets: platform.api.pounces.getTeamMemberPounces_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_member_pounces(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: list[PounceModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_member_pounces_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_team_member_pounces_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_team_member_pounces_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Gets all pounces assigned to a team member  # noqa: E501

        _in snippets: platform.api.pounces.getTeamMemberPounces_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_member_pounces_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: list[PounceModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_member_pounces" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_team_member_pounces`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/pounces/{teamMemberId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PounceModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.org_channels_api import OrgChannelsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestOrgChannelsApi(unittest.TestCase):
    """OrgChannelsApi unit test stubs"""

    def setUp(self):
        self.api = OrgChannelsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_org_channel1(self):
        """Test case for add_org_channel1

        Creates an org channel  # noqa: E501
        """
        pass

    def test_delete_org_channel1(self):
        """Test case for delete_org_channel1

        Delete an org channel  # noqa: E501
        """
        pass

    def test_get_org_channel(self):
        """Test case for get_org_channel

        Gets the details for a specific org channel  # noqa: E501
        """
        pass

    def test_get_org_channel_conversations(self):
        """Test case for get_org_channel_conversations

        Gets the conversation details for a specific org channel  # noqa: E501
        """
        pass

    def test_get_org_channels1(self):
        """Test case for get_org_channels1

        Gets all the org channels for the org  # noqa: E501
        """
        pass

    def test_get_pool_subchannel(self):
        """Test case for get_pool_subchannel

        For pool channels, gets the details of a specific subchannel in the pool  # noqa: E501
        """
        pass

    def test_get_pool_subchannels(self):
        """Test case for get_pool_subchannels

        For pool channels, gets the subchannels in the pool  # noqa: E501
        """
        pass

    def test_update_org_channel(self):
        """Test case for update_org_channel

        Updates an org channel  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.bulk_actions_api import BulkActionsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestBulkActionsApi(unittest.TestCase):
    """BulkActionsApi unit test stubs"""

    def setUp(self):
        self.api = BulkActionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_bulk_action(self):
        """Test case for abort_bulk_action

        Abort a Bulk Action  # noqa: E501
        """
        pass

    def test_add_bulk_action(self):
        """Test case for add_bulk_action

        Creates a Bulk Action and starts it  # noqa: E501
        """
        pass

    def test_disable_variant(self):
        """Test case for disable_variant

        Disable a vairant if the BulkAction is using A/B testing  # noqa: E501
        """
        pass

    def test_get_bulk_action(self):
        """Test case for get_bulk_action

        Gets a specific Bulk Action  # noqa: E501
        """
        pass

    def test_get_bulk_actions(self):
        """Test case for get_bulk_actions

        Gets all Bulk Actions  # noqa: E501
        """
        pass

    def test_get_contacts_for_resolution(self):
        """Test case for get_contacts_for_resolution

        Get a list of customers for a particular Resolution string for this Bulk Action  # noqa: E501
        """
        pass

    def test_get_resolution_counts(self):
        """Test case for get_resolution_counts

        Retrieves the counts for each resolution string for this Bulk Action  # noqa: E501
        """
        pass

    def test_perform_action(self):
        """Test case for perform_action

        Performs an action on the contacts or subset of contacts in the Bulk Action  # noqa: E501
        """
        pass

    def test_set_bulk_resolution(self):
        """Test case for set_bulk_resolution

        Set a bulk action resolution string for a contact.  # noqa: E501
        """
        pass

    def test_unlock_bulk_action_contact(self):
        """Test case for unlock_bulk_action_contact

        Confirms a Bulk Action that is set to require manual sending  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BulkActionModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'org_channels': 'list[OrgChannelModel]',
        'creator_id': 'int',
        'created_timestamp': 'int',
        'fulfillment': 'BulkActionFulfillmentModel',
        'status': 'str',
        'contact_count': 'int',
        'progress': 'int',
        'error_count': 'int',
        'is_manual': 'bool',
        'start_delivery': 'int',
        'delivery_window_start': 'int',
        'delivery_window_end': 'int',
        'use_existing_channels': 'bool',
        'match_area_codes': 'bool',
        'minimum_channels': 'int',
        'is_test_mode': 'bool',
        'description': 'str'
    }

    attribute_map = {
        'id': 'id',
        'org_channels': 'orgChannels',
        'creator_id': 'creatorId',
        'created_timestamp': 'createdTimestamp',
        'fulfillment': 'fulfillment',
        'status': 'status',
        'contact_count': 'contactCount',
        'progress': 'progress',
        'error_count': 'errorCount',
        'is_manual': 'isManual',
        'start_delivery': 'startDelivery',
        'delivery_window_start': 'deliveryWindowStart',
        'delivery_window_end': 'deliveryWindowEnd',
        'use_existing_channels': 'useExistingChannels',
        'match_area_codes': 'matchAreaCodes',
        'minimum_channels': 'minimumChannels',
        'is_test_mode': 'isTestMode',
        'description': 'description'
    }

    def __init__(self, id=None, org_channels=None, creator_id=None, created_timestamp=None, fulfillment=None, status=None, contact_count=None, progress=None, error_count=None, is_manual=None, start_delivery=None, delivery_window_start=None, delivery_window_end=None, use_existing_channels=None, match_area_codes=None, minimum_channels=None, is_test_mode=None, description=None):  # noqa: E501
        """BulkActionModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._org_channels = None
        self._creator_id = None
        self._created_timestamp = None
        self._fulfillment = None
        self._status = None
        self._contact_count = None
        self._progress = None
        self._error_count = None
        self._is_manual = None
        self._start_delivery = None
        self._delivery_window_start = None
        self._delivery_window_end = None
        self._use_existing_channels = None
        self._match_area_codes = None
        self._minimum_channels = None
        self._is_test_mode = None
        self._description = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if org_channels is not None:
            self.org_channels = org_channels
        if creator_id is not None:
            self.creator_id = creator_id
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if fulfillment is not None:
            self.fulfillment = fulfillment
        if status is not None:
            self.status = status
        if contact_count is not None:
            self.contact_count = contact_count
        if progress is not None:
            self.progress = progress
        if error_count is not None:
            self.error_count = error_count
        if is_manual is not None:
            self.is_manual = is_manual
        if start_delivery is not None:
            self.start_delivery = start_delivery
        if delivery_window_start is not None:
            self.delivery_window_start = delivery_window_start
        if delivery_window_end is not None:
            self.delivery_window_end = delivery_window_end
        if use_existing_channels is not None:
            self.use_existing_channels = use_existing_channels
        if match_area_codes is not None:
            self.match_area_codes = match_area_codes
        if minimum_channels is not None:
            self.minimum_channels = minimum_channels
        if is_test_mode is not None:
            self.is_test_mode = is_test_mode
        if description is not None:
            self.description = description

    @property
    def id(self):
        """Gets the id of this BulkActionModel.  # noqa: E501

        The system generated unique id for this Bulk Action.  # noqa: E501

        :return: The id of this BulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BulkActionModel.

        The system generated unique id for this Bulk Action.  # noqa: E501

        :param id: The id of this BulkActionModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def org_channels(self):
        """Gets the org_channels of this BulkActionModel.  # noqa: E501

        The org channels used for sending for message or Instant App actions  # noqa: E501

        :return: The org_channels of this BulkActionModel.  # noqa: E501
        :rtype: list[OrgChannelModel]
        """
        return self._org_channels

    @org_channels.setter
    def org_channels(self, org_channels):
        """Sets the org_channels of this BulkActionModel.

        The org channels used for sending for message or Instant App actions  # noqa: E501

        :param org_channels: The org_channels of this BulkActionModel.  # noqa: E501
        :type: list[OrgChannelModel]
        """

        self._org_channels = org_channels

    @property
    def creator_id(self):
        """Gets the creator_id of this BulkActionModel.  # noqa: E501

        ID of the user that created the Contact List fulfillment.  # noqa: E501

        :return: The creator_id of this BulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this BulkActionModel.

        ID of the user that created the Contact List fulfillment.  # noqa: E501

        :param creator_id: The creator_id of this BulkActionModel.  # noqa: E501
        :type: int
        """

        self._creator_id = creator_id

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this BulkActionModel.  # noqa: E501

        The time the Bulk Action was created.  # noqa: E501

        :return: The created_timestamp of this BulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this BulkActionModel.

        The time the Bulk Action was created.  # noqa: E501

        :param created_timestamp: The created_timestamp of this BulkActionModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def fulfillment(self):
        """Gets the fulfillment of this BulkActionModel.  # noqa: E501


        :return: The fulfillment of this BulkActionModel.  # noqa: E501
        :rtype: BulkActionFulfillmentModel
        """
        return self._fulfillment

    @fulfillment.setter
    def fulfillment(self, fulfillment):
        """Sets the fulfillment of this BulkActionModel.


        :param fulfillment: The fulfillment of this BulkActionModel.  # noqa: E501
        :type: BulkActionFulfillmentModel
        """

        self._fulfillment = fulfillment

    @property
    def status(self):
        """Gets the status of this BulkActionModel.  # noqa: E501

        Status of the bulk action.  # noqa: E501

        :return: The status of this BulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BulkActionModel.

        Status of the bulk action.  # noqa: E501

        :param status: The status of this BulkActionModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["SENDING", "COMPLETED", "ABORTED", "SCHEDULED", "INITIALIZING"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def contact_count(self):
        """Gets the contact_count of this BulkActionModel.  # noqa: E501

        The number of contacts the action will be performed on.  # noqa: E501

        :return: The contact_count of this BulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._contact_count

    @contact_count.setter
    def contact_count(self, contact_count):
        """Sets the contact_count of this BulkActionModel.

        The number of contacts the action will be performed on.  # noqa: E501

        :param contact_count: The contact_count of this BulkActionModel.  # noqa: E501
        :type: int
        """

        self._contact_count = contact_count

    @property
    def progress(self):
        """Gets the progress of this BulkActionModel.  # noqa: E501

        The number of contacts who have been processed so far.  # noqa: E501

        :return: The progress of this BulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this BulkActionModel.

        The number of contacts who have been processed so far.  # noqa: E501

        :param progress: The progress of this BulkActionModel.  # noqa: E501
        :type: int
        """

        self._progress = progress

    @property
    def error_count(self):
        """Gets the error_count of this BulkActionModel.  # noqa: E501

        The number of contacts that an error has occurred on  # noqa: E501

        :return: The error_count of this BulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._error_count

    @error_count.setter
    def error_count(self, error_count):
        """Sets the error_count of this BulkActionModel.

        The number of contacts that an error has occurred on  # noqa: E501

        :param error_count: The error_count of this BulkActionModel.  # noqa: E501
        :type: int
        """

        self._error_count = error_count

    @property
    def is_manual(self):
        """Gets the is_manual of this BulkActionModel.  # noqa: E501

        If there must be a manual button press for each message sent  # noqa: E501

        :return: The is_manual of this BulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._is_manual

    @is_manual.setter
    def is_manual(self, is_manual):
        """Sets the is_manual of this BulkActionModel.

        If there must be a manual button press for each message sent  # noqa: E501

        :param is_manual: The is_manual of this BulkActionModel.  # noqa: E501
        :type: bool
        """

        self._is_manual = is_manual

    @property
    def start_delivery(self):
        """Gets the start_delivery of this BulkActionModel.  # noqa: E501

        When Bulk Action will start sending  # noqa: E501

        :return: The start_delivery of this BulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._start_delivery

    @start_delivery.setter
    def start_delivery(self, start_delivery):
        """Sets the start_delivery of this BulkActionModel.

        When Bulk Action will start sending  # noqa: E501

        :param start_delivery: The start_delivery of this BulkActionModel.  # noqa: E501
        :type: int
        """

        self._start_delivery = start_delivery

    @property
    def delivery_window_start(self):
        """Gets the delivery_window_start of this BulkActionModel.  # noqa: E501

        Start of the window for what time of day messages can be sent  # noqa: E501

        :return: The delivery_window_start of this BulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._delivery_window_start

    @delivery_window_start.setter
    def delivery_window_start(self, delivery_window_start):
        """Sets the delivery_window_start of this BulkActionModel.

        Start of the window for what time of day messages can be sent  # noqa: E501

        :param delivery_window_start: The delivery_window_start of this BulkActionModel.  # noqa: E501
        :type: int
        """

        self._delivery_window_start = delivery_window_start

    @property
    def delivery_window_end(self):
        """Gets the delivery_window_end of this BulkActionModel.  # noqa: E501

        End of the window for what time of day messages can be sent  # noqa: E501

        :return: The delivery_window_end of this BulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._delivery_window_end

    @delivery_window_end.setter
    def delivery_window_end(self, delivery_window_end):
        """Sets the delivery_window_end of this BulkActionModel.

        End of the window for what time of day messages can be sent  # noqa: E501

        :param delivery_window_end: The delivery_window_end of this BulkActionModel.  # noqa: E501
        :type: int
        """

        self._delivery_window_end = delivery_window_end

    @property
    def use_existing_channels(self):
        """Gets the use_existing_channels of this BulkActionModel.  # noqa: E501

        If a prior conversational history exists with a customer, prioritize use of their last used channel if possible  # noqa: E501

        :return: The use_existing_channels of this BulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._use_existing_channels

    @use_existing_channels.setter
    def use_existing_channels(self, use_existing_channels):
        """Sets the use_existing_channels of this BulkActionModel.

        If a prior conversational history exists with a customer, prioritize use of their last used channel if possible  # noqa: E501

        :param use_existing_channels: The use_existing_channels of this BulkActionModel.  # noqa: E501
        :type: bool
        """

        self._use_existing_channels = use_existing_channels

    @property
    def match_area_codes(self):
        """Gets the match_area_codes of this BulkActionModel.  # noqa: E501

        Match the outgoing number area codes to the customer's area code if possible  # noqa: E501

        :return: The match_area_codes of this BulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._match_area_codes

    @match_area_codes.setter
    def match_area_codes(self, match_area_codes):
        """Sets the match_area_codes of this BulkActionModel.

        Match the outgoing number area codes to the customer's area code if possible  # noqa: E501

        :param match_area_codes: The match_area_codes of this BulkActionModel.  # noqa: E501
        :type: bool
        """

        self._match_area_codes = match_area_codes

    @property
    def minimum_channels(self):
        """Gets the minimum_channels of this BulkActionModel.  # noqa: E501

        The minimum amount of channels this bulk action will operate on at a time. Defaults to 1. Must be less than or equal to the total number of channels  # noqa: E501

        :return: The minimum_channels of this BulkActionModel.  # noqa: E501
        :rtype: int
        """
        return self._minimum_channels

    @minimum_channels.setter
    def minimum_channels(self, minimum_channels):
        """Sets the minimum_channels of this BulkActionModel.

        The minimum amount of channels this bulk action will operate on at a time. Defaults to 1. Must be less than or equal to the total number of channels  # noqa: E501

        :param minimum_channels: The minimum_channels of this BulkActionModel.  # noqa: E501
        :type: int
        """

        self._minimum_channels = minimum_channels

    @property
    def is_test_mode(self):
        """Gets the is_test_mode of this BulkActionModel.  # noqa: E501

        Test Mode. All messages will instead be sent as whispers rather than being sent via text  # noqa: E501

        :return: The is_test_mode of this BulkActionModel.  # noqa: E501
        :rtype: bool
        """
        return self._is_test_mode

    @is_test_mode.setter
    def is_test_mode(self, is_test_mode):
        """Sets the is_test_mode of this BulkActionModel.

        Test Mode. All messages will instead be sent as whispers rather than being sent via text  # noqa: E501

        :param is_test_mode: The is_test_mode of this BulkActionModel.  # noqa: E501
        :type: bool
        """

        self._is_test_mode = is_test_mode

    @property
    def description(self):
        """Gets the description of this BulkActionModel.  # noqa: E501

        A name or short description of the bulk action or campaign  # noqa: E501

        :return: The description of this BulkActionModel.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BulkActionModel.

        A name or short description of the bulk action or campaign  # noqa: E501

        :param description: The description of this BulkActionModel.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BulkActionModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BulkActionModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PounceModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'team_member_id': 'int',
        'repeat': 'str',
        'trigger_type': 'str',
        'trigger_value': 'str',
        'action_type': 'str',
        'action_value': 'str'
    }

    attribute_map = {
        'id': 'id',
        'team_member_id': 'teamMemberId',
        'repeat': 'repeat',
        'trigger_type': 'triggerType',
        'trigger_value': 'triggerValue',
        'action_type': 'actionType',
        'action_value': 'actionValue'
    }

    def __init__(self, id=None, team_member_id=None, repeat=None, trigger_type=None, trigger_value=None, action_type=None, action_value=None):  # noqa: E501
        """PounceModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._team_member_id = None
        self._repeat = None
        self._trigger_type = None
        self._trigger_value = None
        self._action_type = None
        self._action_value = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if team_member_id is not None:
            self.team_member_id = team_member_id
        if repeat is not None:
            self.repeat = repeat
        if trigger_type is not None:
            self.trigger_type = trigger_type
        if trigger_value is not None:
            self.trigger_value = trigger_value
        if action_type is not None:
            self.action_type = action_type
        if action_value is not None:
            self.action_value = action_value

    @property
    def id(self):
        """Gets the id of this PounceModel.  # noqa: E501

        Id of the pounce  # noqa: E501

        :return: The id of this PounceModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PounceModel.

        Id of the pounce  # noqa: E501

        :param id: The id of this PounceModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def team_member_id(self):
        """Gets the team_member_id of this PounceModel.  # noqa: E501

        Id of the team member that this pounce applies to  # noqa: E501

        :return: The team_member_id of this PounceModel.  # noqa: E501
        :rtype: int
        """
        return self._team_member_id

    @team_member_id.setter
    def team_member_id(self, team_member_id):
        """Sets the team_member_id of this PounceModel.

        Id of the team member that this pounce applies to  # noqa: E501

        :param team_member_id: The team_member_id of this PounceModel.  # noqa: E501
        :type: int
        """

        self._team_member_id = team_member_id

    @property
    def repeat(self):
        """Gets the repeat of this PounceModel.  # noqa: E501

        Repeat option  # noqa: E501

        :return: The repeat of this PounceModel.  # noqa: E501
        :rtype: str
        """
        return self._repeat

    @repeat.setter
    def repeat(self, repeat):
        """Sets the repeat of this PounceModel.

        Repeat option  # noqa: E501

        :param repeat: The repeat of this PounceModel.  # noqa: E501
        :type: str
        """

        self._repeat = repeat

    @property
    def trigger_type(self):
        """Gets the trigger_type of this PounceModel.  # noqa: E501

        Type of the trigger that will cause the pounce to act  # noqa: E501

        :return: The trigger_type of this PounceModel.  # noqa: E501
        :rtype: str
        """
        return self._trigger_type

    @trigger_type.setter
    def trigger_type(self, trigger_type):
        """Sets the trigger_type of this PounceModel.

        Type of the trigger that will cause the pounce to act  # noqa: E501

        :param trigger_type: The trigger_type of this PounceModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["login", "route", "immediate"]  # noqa: E501
        if trigger_type not in allowed_values:
            raise ValueError(
                "Invalid value for `trigger_type` ({0}), must be one of {1}"  # noqa: E501
                .format(trigger_type, allowed_values)
            )

        self._trigger_type = trigger_type

    @property
    def trigger_value(self):
        """Gets the trigger_value of this PounceModel.  # noqa: E501

        Value of the trigger  # noqa: E501

        :return: The trigger_value of this PounceModel.  # noqa: E501
        :rtype: str
        """
        return self._trigger_value

    @trigger_value.setter
    def trigger_value(self, trigger_value):
        """Sets the trigger_value of this PounceModel.

        Value of the trigger  # noqa: E501

        :param trigger_value: The trigger_value of this PounceModel.  # noqa: E501
        :type: str
        """

        self._trigger_value = trigger_value

    @property
    def action_type(self):
        """Gets the action_type of this PounceModel.  # noqa: E501

        Type of the action that the pounce will perform  # noqa: E501

        :return: The action_type of this PounceModel.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this PounceModel.

        Type of the action that the pounce will perform  # noqa: E501

        :param action_type: The action_type of this PounceModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["overlay", "log"]  # noqa: E501
        if action_type not in allowed_values:
            raise ValueError(
                "Invalid value for `action_type` ({0}), must be one of {1}"  # noqa: E501
                .format(action_type, allowed_values)
            )

        self._action_type = action_type

    @property
    def action_value(self):
        """Gets the action_value of this PounceModel.  # noqa: E501

        Value of the action  # noqa: E501

        :return: The action_value of this PounceModel.  # noqa: E501
        :rtype: str
        """
        return self._action_value

    @action_value.setter
    def action_value(self, action_value):
        """Sets the action_value of this PounceModel.

        Value of the action  # noqa: E501

        :param action_value: The action_value of this PounceModel.  # noqa: E501
        :type: str
        """

        self._action_value = action_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PounceModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PounceModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsAgentActivityReportModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'agent_name': 'str',
        'total_opened_interactions': 'int',
        'completed_interactions': 'int',
        'open_interactions': 'int',
        'ignored_interactions': 'int',
        'responded_interactions': 'int',
        'outgoing_messages_count': 'int',
        'total_conversation_time': 'int',
        'total_response_time': 'int',
        'avg_agent_response_time': 'int',
        'avg_conversation_time': 'int',
        'contact_action_confirms_count': 'int'
    }

    attribute_map = {
        'agent_name': 'agentName',
        'total_opened_interactions': 'totalOpenedInteractions',
        'completed_interactions': 'completedInteractions',
        'open_interactions': 'openInteractions',
        'ignored_interactions': 'ignoredInteractions',
        'responded_interactions': 'respondedInteractions',
        'outgoing_messages_count': 'outgoingMessagesCount',
        'total_conversation_time': 'totalConversationTime',
        'total_response_time': 'totalResponseTime',
        'avg_agent_response_time': 'avgAgentResponseTime',
        'avg_conversation_time': 'avgConversationTime',
        'contact_action_confirms_count': 'contactActionConfirmsCount'
    }

    def __init__(self, agent_name=None, total_opened_interactions=None, completed_interactions=None, open_interactions=None, ignored_interactions=None, responded_interactions=None, outgoing_messages_count=None, total_conversation_time=None, total_response_time=None, avg_agent_response_time=None, avg_conversation_time=None, contact_action_confirms_count=None):  # noqa: E501
        """AnalyticsAgentActivityReportModel - a model defined in Swagger"""  # noqa: E501
        self._agent_name = None
        self._total_opened_interactions = None
        self._completed_interactions = None
        self._open_interactions = None
        self._ignored_interactions = None
        self._responded_interactions = None
        self._outgoing_messages_count = None
        self._total_conversation_time = None
        self._total_response_time = None
        self._avg_agent_response_time = None
        self._avg_conversation_time = None
        self._contact_action_confirms_count = None
        self.discriminator = None
        if agent_name is not None:
            self.agent_name = agent_name
        if total_opened_interactions is not None:
            self.total_opened_interactions = total_opened_interactions
        if completed_interactions is not None:
            self.completed_interactions = completed_interactions
        if open_interactions is not None:
            self.open_interactions = open_interactions
        if ignored_interactions is not None:
            self.ignored_interactions = ignored_interactions
        if responded_interactions is not None:
            self.responded_interactions = responded_interactions
        if outgoing_messages_count is not None:
            self.outgoing_messages_count = outgoing_messages_count
        if total_conversation_time is not None:
            self.total_conversation_time = total_conversation_time
        if total_response_time is not None:
            self.total_response_time = total_response_time
        if avg_agent_response_time is not None:
            self.avg_agent_response_time = avg_agent_response_time
        if avg_conversation_time is not None:
            self.avg_conversation_time = avg_conversation_time
        if contact_action_confirms_count is not None:
            self.contact_action_confirms_count = contact_action_confirms_count

    @property
    def agent_name(self):
        """Gets the agent_name of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The agent's display name.  # noqa: E501

        :return: The agent_name of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: str
        """
        return self._agent_name

    @agent_name.setter
    def agent_name(self, agent_name):
        """Sets the agent_name of this AnalyticsAgentActivityReportModel.

        The agent's display name.  # noqa: E501

        :param agent_name: The agent_name of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: str
        """

        self._agent_name = agent_name

    @property
    def total_opened_interactions(self):
        """Gets the total_opened_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The number of interactions that were opened during the window, or still open at the start of the window.  # noqa: E501

        :return: The total_opened_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._total_opened_interactions

    @total_opened_interactions.setter
    def total_opened_interactions(self, total_opened_interactions):
        """Sets the total_opened_interactions of this AnalyticsAgentActivityReportModel.

        The number of interactions that were opened during the window, or still open at the start of the window.  # noqa: E501

        :param total_opened_interactions: The total_opened_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._total_opened_interactions = total_opened_interactions

    @property
    def completed_interactions(self):
        """Gets the completed_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The number of interactions that were closed during the window.  # noqa: E501

        :return: The completed_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._completed_interactions

    @completed_interactions.setter
    def completed_interactions(self, completed_interactions):
        """Sets the completed_interactions of this AnalyticsAgentActivityReportModel.

        The number of interactions that were closed during the window.  # noqa: E501

        :param completed_interactions: The completed_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._completed_interactions = completed_interactions

    @property
    def open_interactions(self):
        """Gets the open_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The number of interactions that were open at the end of the window.  # noqa: E501

        :return: The open_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._open_interactions

    @open_interactions.setter
    def open_interactions(self, open_interactions):
        """Sets the open_interactions of this AnalyticsAgentActivityReportModel.

        The number of interactions that were open at the end of the window.  # noqa: E501

        :param open_interactions: The open_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._open_interactions = open_interactions

    @property
    def ignored_interactions(self):
        """Gets the ignored_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The number of interactions that were ignored during the window.  # noqa: E501

        :return: The ignored_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._ignored_interactions

    @ignored_interactions.setter
    def ignored_interactions(self, ignored_interactions):
        """Sets the ignored_interactions of this AnalyticsAgentActivityReportModel.

        The number of interactions that were ignored during the window.  # noqa: E501

        :param ignored_interactions: The ignored_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._ignored_interactions = ignored_interactions

    @property
    def responded_interactions(self):
        """Gets the responded_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The number of interactions that were responded to during the window.  # noqa: E501

        :return: The responded_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._responded_interactions

    @responded_interactions.setter
    def responded_interactions(self, responded_interactions):
        """Sets the responded_interactions of this AnalyticsAgentActivityReportModel.

        The number of interactions that were responded to during the window.  # noqa: E501

        :param responded_interactions: The responded_interactions of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._responded_interactions = responded_interactions

    @property
    def outgoing_messages_count(self):
        """Gets the outgoing_messages_count of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The number of messages that were sent during the window.  # noqa: E501

        :return: The outgoing_messages_count of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_count

    @outgoing_messages_count.setter
    def outgoing_messages_count(self, outgoing_messages_count):
        """Sets the outgoing_messages_count of this AnalyticsAgentActivityReportModel.

        The number of messages that were sent during the window.  # noqa: E501

        :param outgoing_messages_count: The outgoing_messages_count of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_count = outgoing_messages_count

    @property
    def total_conversation_time(self):
        """Gets the total_conversation_time of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The total time (in ms) between the opening event and the time the interaction was completed.  # noqa: E501

        :return: The total_conversation_time of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._total_conversation_time

    @total_conversation_time.setter
    def total_conversation_time(self, total_conversation_time):
        """Sets the total_conversation_time of this AnalyticsAgentActivityReportModel.

        The total time (in ms) between the opening event and the time the interaction was completed.  # noqa: E501

        :param total_conversation_time: The total_conversation_time of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._total_conversation_time = total_conversation_time

    @property
    def total_response_time(self):
        """Gets the total_response_time of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The total time (in ms) between the opening event and the time the interaction was first responded to.  # noqa: E501

        :return: The total_response_time of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._total_response_time

    @total_response_time.setter
    def total_response_time(self, total_response_time):
        """Sets the total_response_time of this AnalyticsAgentActivityReportModel.

        The total time (in ms) between the opening event and the time the interaction was first responded to.  # noqa: E501

        :param total_response_time: The total_response_time of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._total_response_time = total_response_time

    @property
    def avg_agent_response_time(self):
        """Gets the avg_agent_response_time of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The average time (in ms) between the opening event and the time the interaction was first responded to.  # noqa: E501

        :return: The avg_agent_response_time of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._avg_agent_response_time

    @avg_agent_response_time.setter
    def avg_agent_response_time(self, avg_agent_response_time):
        """Sets the avg_agent_response_time of this AnalyticsAgentActivityReportModel.

        The average time (in ms) between the opening event and the time the interaction was first responded to.  # noqa: E501

        :param avg_agent_response_time: The avg_agent_response_time of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._avg_agent_response_time = avg_agent_response_time

    @property
    def avg_conversation_time(self):
        """Gets the avg_conversation_time of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The average time (in ms) between the opening event and the time the interaction was completed.  # noqa: E501

        :return: The avg_conversation_time of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._avg_conversation_time

    @avg_conversation_time.setter
    def avg_conversation_time(self, avg_conversation_time):
        """Sets the avg_conversation_time of this AnalyticsAgentActivityReportModel.

        The average time (in ms) between the opening event and the time the interaction was completed.  # noqa: E501

        :param avg_conversation_time: The avg_conversation_time of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._avg_conversation_time = avg_conversation_time

    @property
    def contact_action_confirms_count(self):
        """Gets the contact_action_confirms_count of this AnalyticsAgentActivityReportModel.  # noqa: E501

        The number of contact action messages that were confirmed during the window.  # noqa: E501

        :return: The contact_action_confirms_count of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :rtype: int
        """
        return self._contact_action_confirms_count

    @contact_action_confirms_count.setter
    def contact_action_confirms_count(self, contact_action_confirms_count):
        """Sets the contact_action_confirms_count of this AnalyticsAgentActivityReportModel.

        The number of contact action messages that were confirmed during the window.  # noqa: E501

        :param contact_action_confirms_count: The contact_action_confirms_count of this AnalyticsAgentActivityReportModel.  # noqa: E501
        :type: int
        """

        self._contact_action_confirms_count = contact_action_confirms_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsAgentActivityReportModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsAgentActivityReportModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddCustomerModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_name': 'str',
        'identities': 'list[CustomerIdentityModel]',
        'tag_ids': 'list[int]',
        'global_opt_out': 'bool',
        'data': 'dict(str, str)'
    }

    attribute_map = {
        'display_name': 'displayName',
        'identities': 'identities',
        'tag_ids': 'tagIds',
        'global_opt_out': 'globalOptOut',
        'data': 'data'
    }

    def __init__(self, display_name=None, identities=None, tag_ids=None, global_opt_out=None, data=None):  # noqa: E501
        """AddCustomerModel - a model defined in Swagger"""  # noqa: E501
        self._display_name = None
        self._identities = None
        self._tag_ids = None
        self._global_opt_out = None
        self._data = None
        self.discriminator = None
        if display_name is not None:
            self.display_name = display_name
        if identities is not None:
            self.identities = identities
        if tag_ids is not None:
            self.tag_ids = tag_ids
        if global_opt_out is not None:
            self.global_opt_out = global_opt_out
        if data is not None:
            self.data = data

    @property
    def display_name(self):
        """Gets the display_name of this AddCustomerModel.  # noqa: E501

        The display name of this user.  # noqa: E501

        :return: The display_name of this AddCustomerModel.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this AddCustomerModel.

        The display name of this user.  # noqa: E501

        :param display_name: The display_name of this AddCustomerModel.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def identities(self):
        """Gets the identities of this AddCustomerModel.  # noqa: E501

        Optional. A collection of identities for this user  # noqa: E501

        :return: The identities of this AddCustomerModel.  # noqa: E501
        :rtype: list[CustomerIdentityModel]
        """
        return self._identities

    @identities.setter
    def identities(self, identities):
        """Sets the identities of this AddCustomerModel.

        Optional. A collection of identities for this user  # noqa: E501

        :param identities: The identities of this AddCustomerModel.  # noqa: E501
        :type: list[CustomerIdentityModel]
        """

        self._identities = identities

    @property
    def tag_ids(self):
        """Gets the tag_ids of this AddCustomerModel.  # noqa: E501

        A collection of tags to associate with the customer  # noqa: E501

        :return: The tag_ids of this AddCustomerModel.  # noqa: E501
        :rtype: list[int]
        """
        return self._tag_ids

    @tag_ids.setter
    def tag_ids(self, tag_ids):
        """Sets the tag_ids of this AddCustomerModel.

        A collection of tags to associate with the customer  # noqa: E501

        :param tag_ids: The tag_ids of this AddCustomerModel.  # noqa: E501
        :type: list[int]
        """

        self._tag_ids = tag_ids

    @property
    def global_opt_out(self):
        """Gets the global_opt_out of this AddCustomerModel.  # noqa: E501

        Whether the customer will be opted out of messaging across all channels  # noqa: E501

        :return: The global_opt_out of this AddCustomerModel.  # noqa: E501
        :rtype: bool
        """
        return self._global_opt_out

    @global_opt_out.setter
    def global_opt_out(self, global_opt_out):
        """Sets the global_opt_out of this AddCustomerModel.

        Whether the customer will be opted out of messaging across all channels  # noqa: E501

        :param global_opt_out: The global_opt_out of this AddCustomerModel.  # noqa: E501
        :type: bool
        """

        self._global_opt_out = global_opt_out

    @property
    def data(self):
        """Gets the data of this AddCustomerModel.  # noqa: E501

        Values to store in the customer data store  # noqa: E501

        :return: The data of this AddCustomerModel.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this AddCustomerModel.

        Values to store in the customer data store  # noqa: E501

        :param data: The data of this AddCustomerModel.  # noqa: E501
        :type: dict(str, str)
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddCustomerModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddCustomerModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
